import { JSX } from 'solid-js';
export declare type ToastType = 'success' | 'error' | 'loading' | 'blank' | 'custom';
export declare type ToastPosition = 'top-left' | 'top-center' | 'top-right' | 'bottom-left' | 'bottom-center' | 'bottom-right';
export declare type Renderable = JSX.Element | string | null;
export declare type ValueFunction<TValue, TArg> = (arg: TArg) => TValue;
export declare type ValueOrFunction<TValue, TArg> = TValue | ValueFunction<TValue, TArg>;
export declare const resolveValue: <TValue, TArg>(valOrFunction: ValueOrFunction<TValue, TArg>, arg: TArg) => TValue;
export interface IconTheme {
    primary?: string;
    secondary?: string;
}
export interface Toast {
    type: ToastType;
    id: string;
    message: ValueOrFunction<Renderable, Toast>;
    icon?: Renderable;
    duration?: number;
    pauseDuration: number;
    paused: boolean;
    position?: ToastPosition;
    ariaProps: {
        role: 'status' | 'alert';
        'aria-live': 'assertive' | 'off' | 'polite';
    };
    style?: JSX.CSSProperties;
    className?: string;
    iconTheme?: IconTheme;
    createdAt: number;
    updatedAt?: number;
    visible: boolean;
    height?: number;
    unmountDelay: number;
}
export declare type ToastOptions = Partial<Pick<Toast, 'id' | 'icon' | 'duration' | 'ariaProps' | 'className' | 'style' | 'position' | 'unmountDelay' | 'iconTheme'>>;
export declare type ToastTimeouts = {
    [key in ToastType]: number;
};
export declare type DefaultToastOptions = ToastOptions;
export declare type Message = ValueOrFunction<Renderable, Toast>;
export declare type ToastHandler = (message: Message, options?: ToastOptions) => string;
export interface ToasterProps {
    position?: ToastPosition;
    toastOptions?: DefaultToastOptions;
    gutter?: number;
    containerStyle?: JSX.CSSProperties;
    containerClassName?: string;
}
export interface ToastContainerProps {
    toast: Toast;
}
export interface ToastBarProps {
    toast: Toast;
    position: ToastPosition;
}
export declare type IconProps = Partial<IconTheme>;
